@@ -5,7 +5,6 @@
 #'
 #' @param x A named list of equal-length vectors. The lengths are not checked; it is the responsibility
 #'   of the caller to make sure they are equal.
-#' @param n Number of rows. If `NULL`, will be computed from the length of the first element of `x`.
 #'
 #' @export
 #'
@@ -13,6 +12,6 @@
 #' l <- list(x = 1:3, y = c("a", "a", "b"))
 #'
 #' new_tidytable(l)
-new_tidytable <- function(x = list(), n = NULL) {
-  new_data_frame(x, n, class = c("tidytable", "data.table"))
+new_tidytable <- function(x = list()) {
+  new_data_frame(x, class = c("tidytable", "data.table"))
 }
