@@ -28,14 +28,6 @@ map <- function(.x, .f, ...) {
   lapply(.x, .f, ...)
 }
 
-#' @export
-#' @keywords internal
-#' @inherit map
-map. <- function(.x, .f, ...) {
-  deprecate_dot_fun()
-  map(.x, .f, ...)
-}
-
 #' @export
 #' @rdname map
 map_lgl <- function(.x, .f, ...) {
@@ -43,14 +35,6 @@ map_lgl <- function(.x, .f, ...) {
   vapply(.x, .f, logical(1), ...)
 }
 
-#' @export
-#' @keywords internal
-#' @inherit map
-map_lgl. <- function(.x, .f, ...) {
-  deprecate_dot_fun()
-  map_lgl(.x, .f, ...)
-}
-
 #' @export
 #' @rdname map
 map_int <- function(.x, .f, ...) {
@@ -58,14 +42,6 @@ map_int <- function(.x, .f, ...) {
   vapply(.x, .f, integer(1), ...)
 }
 
-#' @export
-#' @keywords internal
-#' @inherit map
-map_int. <- function(.x, .f, ...) {
-  deprecate_dot_fun()
-  map_int(.x, .f, ...)
-}
-
 #' @export
 #' @rdname map
 map_dbl <- function(.x, .f, ...) {
@@ -73,14 +49,6 @@ map_dbl <- function(.x, .f, ...) {
   vapply(.x, .f, double(1), ...)
 }
 
-#' @export
-#' @keywords internal
-#' @inherit map
-map_dbl. <- function(.x, .f, ...) {
-  deprecate_dot_fun()
-  map_dbl(.x, .f, ...)
-}
-
 #' @export
 #' @rdname map
 map_chr <- function(.x, .f, ...) {
@@ -88,14 +56,6 @@ map_chr <- function(.x, .f, ...) {
   vapply(.x, .f, character(1), ...)
 }
 
-#' @export
-#' @keywords internal
-#' @inherit map
-map_chr. <- function(.x, .f, ...) {
-  deprecate_dot_fun()
-  map_chr(.x, .f, ...)
-}
-
 #' @export
 #' @rdname map
 map_dfc <- function(.x, .f, ...) {
@@ -103,14 +63,6 @@ map_dfc <- function(.x, .f, ...) {
   bind_cols(result_list)
 }
 
-#' @export
-#' @keywords internal
-#' @inherit map
-map_dfc. <- function(.x, .f, ...) {
-  deprecate_dot_fun()
-  map_dfc(.x, .f, ...)
-}
-
 #' @export
 #' @rdname map
 map_dfr <- function(.x, .f, ..., .id = NULL) {
@@ -122,22 +74,6 @@ map_dfr <- function(.x, .f, ..., .id = NULL) {
 #' @rdname map
 map_df <- map_dfr
 
-#' @export
-#' @keywords internal
-#' @inherit map
-map_dfr. <- function(.x, .f, ..., .id = NULL) {
-  deprecate_dot_fun()
-  map_dfr(.x, .f, ..., .id = .id)
-}
-
-#' @export
-#' @keywords internal
-#' @inherit map
-map_df. <- function(.x, .f, ..., .id = NULL) {
-  deprecate_dot_fun()
-  map_df(.x, .f, ..., .id = .id)
-}
-
 #' @export
 #' @rdname map
 walk <- function(.x, .f, ...) {
@@ -145,14 +81,6 @@ walk <- function(.x, .f, ...) {
   invisible(.x)
 }
 
-#' @export
-#' @keywords internal
-#' @inherit map
-walk. <- function(.x, .f, ...) {
-  deprecate_dot_fun()
-  walk(.x, .f, ...)
-}
-
 #' @export
 #' @rdname map
 map_vec <- function(.x, .f, ..., .ptype = NULL) {
