@@ -3,37 +3,12 @@
 slice_max <- function(.df, order_by, n = 1, ..., with_ties = TRUE,
                       .by = NULL, by = NULL) {
   check_required(order_by)
-
-  .df <- .df_as_tidytable(.df)
-
-  if (is_ungrouped(.df)) {
-    tt_slice_max(
-      .df, {{ order_by }}, {{ n }}, with_ties = with_ties,
-      .by = {{ .by }}, by = {{ by }}
-    )
-  } else {
-    .by <- group_vars(.df)
-    tt_slice_max(
-      .df, {{ order_by }}, {{ n }}, with_ties = with_ties, .by = all_of(.by)
-    )
-  }
+  UseMethod("slice_max")
 }
 
 #' @export
-#' @keywords internal
-#' @inherit slice
-slice_max. <- function(.df, order_by, n = 1, ..., with_ties = TRUE,
-                       .by = NULL, by = NULL) {
-  check_required(order_by)
-  deprecate_dot_fun()
-  slice_max(
-    .df, {{ order_by }}, {{ n }}, with_ties = with_ties,
-    .by = {{ .by }}, by = {{ by }}
-  )
-}
-
-tt_slice_max <- function(.df, order_by, n = 1, ..., with_ties = TRUE,
-                         .by = NULL, by = NULL) {
+slice_max.tidytable <- function(.df, order_by, n = 1, ..., with_ties = TRUE,
+                                 .by = NULL, by = NULL) {
   if (is_true(with_ties)) {
     .df %>%
       filter(
@@ -48,43 +23,38 @@ tt_slice_max <- function(.df, order_by, n = 1, ..., with_ties = TRUE,
   }
 }
 
+#' @export
+slice_max.grouped_tt <- function(.df, order_by, n = 1, ..., with_ties = TRUE,
+                                 .by = NULL, by = NULL) {
+  .by <- group_vars(.df)
+  out <- ungroup(.df)
+  out <- slice_max(
+    out, {{ order_by }}, {{ n }}, with_ties = with_ties, .by = all_of(.by)
+  )
+  group_by(out, all_of(.by))
+}
+
+#' @export
+slice_max.data.frame <- function(.df, order_by, n = 1, ..., with_ties = TRUE,
+                                 .by = NULL, by = NULL) {
+  .df <- as_tidytable(.df)
+  slice_max(
+    .df, {{ order_by }}, {{ n }}, with_ties = with_ties,
+    .by = {{ .by }}, by = {{ by }}
+  )
+}
 
 #' @export
 #' @rdname slice
 slice_min <- function(.df, order_by, n = 1, ..., with_ties = TRUE,
                       .by = NULL, by = NULL) {
   check_required(order_by)
-
-  .df <- .df_as_tidytable(.df)
-
-  if (is_ungrouped(.df)) {
-    tt_slice_min(
-      .df, {{ order_by }}, {{ n }}, with_ties = with_ties,
-      .by = {{ .by }}, by = {{ by }}
-    )
-  } else {
-    .by <- group_vars(.df)
-    tt_slice_min(
-      .df, {{ order_by }}, {{ n }}, with_ties = with_ties, .by = all_of(.by)
-    )
-  }
+  UseMethod("slice_min")
 }
 
 #' @export
-#' @keywords internal
-#' @inherit slice
-slice_min. <- function(.df, order_by, n = 1, ..., with_ties = TRUE,
-                       .by = NULL, by = NULL) {
-  check_required(order_by)
-  deprecate_dot_fun()
-  slice_min(
-    .df, {{ order_by }}, {{ n }}, with_ties = with_ties,
-    .by = {{ .by }}, by = {{ by }}
-  )
-}
-
-tt_slice_min <- function(.df, order_by, n = 1, ..., with_ties = TRUE,
-                         .by = NULL, by = NULL) {
+slice_min.tidytable <- function(.df, order_by, n = 1, ..., with_ties = TRUE,
+                                .by = NULL, by = NULL) {
   if (is_true(with_ties)) {
     .df %>%
       filter(
@@ -99,4 +69,24 @@ tt_slice_min <- function(.df, order_by, n = 1, ..., with_ties = TRUE,
   }
 }
 
+#' @export
+slice_min.grouped_tt <- function(.df, order_by, n = 1, ..., with_ties = TRUE,
+                                 .by = NULL, by = NULL) {
+  .by <- group_vars(.df)
+  out <- ungroup(.df)
+  out <- slice_min(
+    out, {{ order_by }}, {{ n }}, with_ties = with_ties, .by = any_of(.by)
+  )
+  group_by(out, any_of(.by))
+}
+
+#' @export
+slice_min.data.frame <- function(.df, order_by, n = 1, ..., with_ties = TRUE,
+                                 .by = NULL, by = NULL) {
+  .df <- as_tidytable(.df)
+  slice_min(
+    .df, {{ order_by }}, {{ n }}, with_ties = with_ties,
+    .by = {{ .by }}, by = {{ by }}
+  )
+}
 
