@@ -23,8 +23,11 @@
 #' df %>%
 #'   top_n(2, wt = y, .by = z)
 top_n <- function(.df, n = 5, wt = NULL, .by = NULL) {
-  .df <- .df_as_tidytable(.df)
+  UseMethod("top_n")
+}
 
+#' @export
+top_n.tidytable <- function(.df, n = 5, wt = NULL, .by = NULL) {
   wt <- enquo(wt)
 
   if (quo_is_null(wt)) {
@@ -35,10 +38,8 @@ top_n <- function(.df, n = 5, wt = NULL, .by = NULL) {
 }
 
 #' @export
-#' @keywords internal
-#' @inherit top_n
-top_n. <- function(.df, n = 5, wt = NULL, .by = NULL) {
-  deprecate_dot_fun()
+top_n.data.frame <- function(.df, n = 5, wt = NULL, .by = NULL) {
+  .df <- as_tidytable(.df)
   top_n(.df, {{ n }}, {{ wt }}, .by = {{ .by }})
 }
 
